/**
 * Copyright (c) 2007, Opera Software ASA
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Opera Software ASA nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY OPERA SOFTWARE ASA AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL OPERA SOFTWARE ASA AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
* Function mediaQuery() takes a string argument representing a css media-query.
* Returns a boolean, true if it matches the device, false otherwise.
* 
* Example usage:
* if (mediaQuery("handheld")) { ... }
* or
* if (mediaQuery("tv and (max-height: 400px)") { ... }
*/

function mediaQuery(str)
{
  var style = document.createElement('style');
  var div = document.createElement('div');
  var id = '';
  do {
    id = ('x'+Math.random()).replace(/\./,''); /* loop ensures no namespace collision */
  }
  while ( document.getElementById(id) );
  div.id = id;
  style.innerText = '@media ' + str + ' { #'+id+' { display:none; } }';
  document.documentElement.appendChild(style);
  document.documentElement.appendChild(div);
  var ret = getComputedStyle(div,null).getPropertyValue('display') == 'none';
  style.parentNode.removeChild(style);
  div.parentNode.removeChild(div);
  return ret;
}
